@@ -12,32 +12,6 @@ if TYPE_CHECKING:
     T = TypeVar("T", bound=EnumType)
 
 
-class _CaseInsensitiveGetItem(EnumType):
-    def __getitem__(self: type[T], name: str) -> T:  # type: ignore[misc]
-        if not isinstance(name, str):
-            raise KeyError(name)
-
-        for key, value in self._member_map_.items():
-            if key.casefold() == name.casefold():
-                return value  # type: ignore[return-value]
-        raise KeyError(name)
-
-
-class CaseInsensitiveStrEnum(StrEnum, metaclass=_CaseInsensitiveGetItem):
-    """A subclass of `StrEnum` that supports case-insensitive lookup."""
-
-    @classmethod
-    def _missing_(cls, value: object) -> Self:
-        msg = f"'{value}' is not a valid {cls.__name__}"
-
-        if isinstance(value, str):
-            for member in cls:
-                if member.value.casefold() == value.casefold():
-                    return member
-            raise ValueError(msg)
-        raise ValueError(msg)
-
-
 class DuplicateFreeStrEnum(StrEnum):
     """
     A subclass of `StrEnum` that ensures all members have unique values and names,
@@ -57,6 +31,39 @@ class DuplicateFreeStrEnum(StrEnum):
                 raise ValueError(msg)
 
 
+class _CaseInsensitiveGetItemAndContains(EnumType):
+    def __contains__(self: type[T], value: object) -> bool:  # type: ignore[misc]
+        if isinstance(value, self):
+            return True
+        if isinstance(value, str):
+            return any(value.casefold() == _value.casefold() for _value in self._value2member_map_)
+        return False
+
+    def __getitem__(self: type[T], name: str) -> T:  # type: ignore[misc]
+        if not isinstance(name, str):
+            raise KeyError(name)
+
+        for key, value in self._member_map_.items():
+            if key.casefold() == name.casefold():
+                return value  # type: ignore[return-value]
+        raise KeyError(name)
+
+
+class CaseInsensitiveStrEnum(DuplicateFreeStrEnum, metaclass=_CaseInsensitiveGetItemAndContains):
+    """A subclass of `DuplicateFreeStrEnum` that supports case-insensitive lookup."""
+
+    @classmethod
+    def _missing_(cls, value: object) -> Self:
+        msg = f"'{value}' is not a valid {cls.__name__}"
+
+        if isinstance(value, str):
+            for member in cls:
+                if member.value.casefold() == value.casefold():
+                    return member
+            raise ValueError(msg)
+        raise ValueError(msg)
+
+
 class _DoubleSidedGetItemAndContains(EnumType):
     def __contains__(self: type[T], value: object) -> bool:  # type: ignore[misc]
         if isinstance(value, self):
@@ -100,8 +107,8 @@ class _DoubleSidedCaseInsensitiveGetItemAndContains(EnumType):
         if isinstance(value, self):
             return True
         if isinstance(value, str):
-            for name, member in self.__members__.items():  # type: ignore[attr-defined]
-                if (value.casefold() == name.casefold()) or (member.value.casefold() == member.value.casefold()):
+            for name, member in self._member_map_.items():
+                if (value.casefold() == name.casefold()) or (value.casefold() == member.value.casefold()):
                     return True
         return False
 
